### Name: blockpick
### Title: Function to show potential block assignments
### Aliases: blockpick blockpick.big
### Keywords: array design

### ** Examples

## look at possibilities for running a 32 run full factorial in 8 blocks
## running this without alias.block.2fis=TRUE throws an error: not possible
## Not run: blockpick(5,0,3)
## the 10th design with block generators 3,12,21 has the most clear 2fis
blockpick(5,0,3,alias.block.2fis=TRUE)
## function FrF2 can be used to manually accomodate this design
des32.5fac.8blocks.MaxC2 <- FrF2(32,5,blocks=c(3,12,21))
design.info(des32.5fac.8blocks.MaxC2)

## look at possibilities for blocking design 7-3.1 from Chen, Sun, Wu catalogue
blockpick(4,design="7-3.1",k.block=2,alias.block.2fis=TRUE)

## big design
## running this throws an error on many machines because of too little memory
## Not run: blockpick(6,design="7-1.2",k.block=5,alias.block.2fis=TRUE)
## for obtaining a design for this scenario with blockpick.big, 
## the number of factors must be increased to 7+k.block=12
## designs 12-6.1 and 12-6.2 dont do it, 12-6.3 does
bpb <- blockpick.big(6,design="12-6.3",k.block=5,alias.block.2fis=TRUE)
bpb
## based on the result of blockpick.big, a blocked design can be obtained as follows:
des64.7fac.32blocks <- FrF2(64,gen=bpb$gen[1,], blocks = as.list(1:5), 
   alias.block.2fis=TRUE)
str(des64.7fac.32blocks)
## if the seven factors are to be named A,...,G:
des64.7fac.32blocks <- FrF2(64,gen=bpb$gen[1,], blocks = as.list(1:5), 
   alias.block.2fis=TRUE, factor.names=c(paste("b",1:5,sep=""),Letters[1:7]))
str(des64.7fac.32blocks)




